class my_pack:
    from sklearn.model_selection import train_test_split
    from sklearn.ensemble import RandomForestClassifier
    from sklearn.model_selection import cross_val_score
    from sklearn.svm import SVC
    from sklearn.datasets import load_iris
    from sklearn.tree import DecisionTreeClassifier
    from sklearn.metrics import accuracy_score, recall_score, confusion_matrix
    from sklearn.model_selection import GridSearchCV, RandomizedSearchCV
    from sklearn.pipeline import Pipeline
    from sklearn.preprocessing import StandardScaler
    from sklearn import preprocessing
    from sklearn import decomposition
    from sklearn.decomposition import PCA


from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name='RiteshAwesomeMLlibraries',
    version='0.0.2',
    description='ML Module Collection',
    long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url='',
    author='Ritesh Yadav',
    author_email='daydreamingguy941@gmail.com',
    license='MIT',
    classifiers=classifiers,
    keywords='Machine Learning',
    packages=find_packages(),
    install_requires=['']
)